@@ -13,7 +13,7 @@ from explainaboard import (
     TaskType,
 )
 from explainaboard.analyzers import get_pairwise_performance_gap
-from explainaboard.analyzers.draw_hist import draw_bar_chart_from_report
+from explainaboard.analyzers.draw_hist import draw_bar_chart_from_reports
 from explainaboard.constants import Source
 from explainaboard.info import SysOutputInfo
 from explainaboard.loaders.file_loader import DatalabLoaderOption
@@ -197,6 +197,14 @@ def create_parser():
         help="the name of sub-dataset",
     )
 
+    parser.add_argument(
+        '--split',
+        type=str,
+        required=False,
+        default='test',
+        help="the name of the split within the dataset",
+    )
+
     parser.add_argument(
         '--language',
         type=str,
@@ -327,6 +335,7 @@ def main():
         custom_dataset_paths: list[str] | None = args.custom_dataset_paths
         dataset: str | None = args.dataset
         sub_dataset: str | None = args.sub_dataset
+        split: str = args.split
 
         if custom_dataset_paths:  # load custom datasets
             loaders = [
@@ -353,7 +362,7 @@ def main():
             loaders = [
                 get_datalab_loader(
                     task,
-                    DatalabLoaderOption(dataset, sub_dataset),
+                    DatalabLoaderOption(dataset, sub_dataset, split=split),
                     sys_output,
                     Source.local_filesystem,
                     output_file_type,
@@ -386,6 +395,7 @@ def main():
         metadata = {
             "dataset_name": dataset,
             "sub_dataset_name": sub_dataset,
+            "split_name": split,
             "language": args.language,
             "reload_stat": reload_stat,
             "conf_value": args.conf_value,
@@ -425,8 +435,8 @@ def main():
             # generate figures and save them into  `output_dir_figures`
             if not os.path.exists(f"{output_dir_figures}/{x_file_name}"):
                 os.makedirs(f"{output_dir_figures}/{x_file_name}")
-            draw_bar_chart_from_report(
-                f"{output_dir_reports}/{x_file_name}.json",
+            draw_bar_chart_from_reports(
+                [f"{output_dir_reports}/{x_file_name}.json"],
                 f"{output_dir_figures}/{x_file_name}",
             )
 
