@@ -2,15 +2,20 @@ from explainaboard.loaders import (
     aspect_based_sentiment_classification,
     conditional_generation,
     extractive_qa,
+    file_loader,
     kg_link_tail_prediction,
     loader,
+    loader_registry,
     named_entity_recognition,
     qa_multiple_choice,
     text_classification,
     text_pair_classification,
+    word_segmentation,
 )
 
-get_loader = loader.get_loader
+get_datalab_loader = loader_registry.get_datalab_loader
+get_custom_dataset_loader = loader_registry.get_custom_dataset_loader
+DatalabLoaderOption = file_loader.DatalabLoaderOption
 
 __all__ = [
     'aspect_based_sentiment_classification',
@@ -22,4 +27,5 @@ __all__ = [
     'qa_multiple_choice',
     'text_classification',
     'text_pair_classification',
+    'word_segmentation',
 ]
