@@ -1,6 +1,7 @@
 import unittest
+
+from explainaboard import TaskType
 from explainaboard.table_schema import table_schemas
-from explainaboard.tasks import TaskType
 
 
 class TestTableSchema(unittest.TestCase):
